EagerInductiveDataset
=====================

.. currentmodule:: pykeen.datasets.inductive

.. autoclass:: EagerInductiveDataset
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~EagerInductiveDataset.create_inverse_triples
      ~EagerInductiveDataset.inductive_validation

   .. rubric:: Attributes Documentation

   .. autoattribute:: create_inverse_triples
   .. autoattribute:: inductive_validation
